# 多线程下载

## 使用方法

import autoDownload

autoDownload.AutoDownload(url,file,key=values...)

## 关于作者

作者主页[宽宽2007](https://kuankuan2007.gitee.io "作者主页")

本项目在[苟浩铭/多线程下载 (gitee.com)](https://gitee.com/kuankuan2007/multithreaded-download)上开源
